
# q-expansion of newform 690.2.m.e, downloaded from the LMFDB on 08 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 690
weight = 2
poly_data = [1849, 9761, 32892, 45635, 67716, 33738, 39054, -6818, -12654, -2728, 18393, -12826, 2670, 1484, -1084, 232, 44, -47, 21, -6, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[1282501612989148664802591440192437865851206148, 155149536219470382028278382849012607564855234, 4093173247519912655547594666891603070991037629, 429168271924813826882099674086854348346316447, 501451131662954809161208715479125230370054230, 254107731156110911456925860829019535680643560, 506413793945504308558179543664382039551478381, -1545778996551534493823027843485488731623429641, 1510213948465583906860664866729897854092405040, -645523054820224822996562847878783741124860578, 23679555225596324691136613668401968787295085, 121232248464973597469071218231924604079273476, -59396243271996973471536214813825833953686758, 7993570276087805587822045773392365226429375, 4675929718034584402507169856523433689418728, -3355605389888918251448684246427668451344624, 1311394040786043345900733210851605013731719, -341347209549095925043373153032954895130046, 53002909793216217716103381771629322953753, -1062232799666526981610266069020507709845], 1251744904236946678578002089704411192750995227], [[19932992933324510851205835367781802466046351, 45962070260210116191866899208565750686262100, 121691720948597776211007841065850808930923177, 42673291795579784098732669488188147500283964, 84747560353070862861436710555269500775188548, -6197557511575895313745847085984052444613579, -17532737902844815270275677969854083807675539, -23923971644833757033235931414115756021466960, 47654941565463109441234971374784554240974432, -26660674849651175137939393889742678267358024, 3254662645306260315615832147272217235755284, 4083705827658253067402199555494940593179306, -2289227865431978475040530644074531588778757, 360737171782544685737729351130281051366845, 145973493066613809849563276808615399232117, -111244627427318299468102141675231097776088, 45002235947876337545845078486521082500713, -11791802467768609966958568504277455670596, 1683659807163463335030398634562940124481, 58717743516419735427301297404321138018], 29110346610161550664604699760567702156999889], [[1956963518760247014852696863393523855447836693, 3394618894845027609722741735510662202139340639, 5182887323251194043745225101574543691912349483, 2128833890140323544729630250851779982626901099, 4034945813804444076755749401172797043727693111, -2997491503926361191825030627790655705856145046, -2146518156541398615727581337473132458530265958, 1398284387450911692066093278696256839999568845, 1809434319916765969775905135782251177324316065, -2336602941192259630452367534468861595592246986, 979206657918798440703405795122310740320011686, 17011587915326236426270052476242460761422293, -190039222271714451166335678875670982947759289, 78838949511659225559744438641649996257215392, -7282369126889754252037428867416700807308739, -6676055021002159185337935572334014463461290, 4363747059996434801331861730610851049027696, -1614712915063581482915126082801617380007416, 383820117790434419975339611012598688166801, -44158878386388837684763466776594883481688], 1251744904236946678578002089704411192750995227], [[-45676010385660660209241440967881831523335, -30066745752248689178374168541677838176907051, -4420662731769809011800075683517096445513418, -96317400961225456147753003696543114891391028, -11653451818303078324856289563177838335492569, -12495087019955909220157578421296258592669880, -6874236532890405958063562602059219622812330, -11608639319008789013896761618739539953157097, 36260941637174761075542422100531958981018797, -35053864590420781889647257230083951373487160, 14557800161301357958693144745843942856225151, -233845519466824409883798629468486904670305, -2885311861397284290929549503167659527082782, 1344648599937019707693641394590683732843646, -159118835377890473017593426850561276022265, -114473668082726015400947711268283522746576, 76950398760548629401344942776529444467708, -29336490679109687855001179200177701194628, 7419542343165089730919943385663354261007, -1084407278958536182010274078081541318481], 29110346610161550664604699760567702156999889], [[8622523297307969655205844306366864200101128, -13678322485755541407599447455175616448335861, -21232534134530520619231910908516695777312092, -101346991652100504562782922544152993252223301, 24621632731588276839402235163775354236815130, -90221640387925430285270553988365669236875605, -20064327691260266596883521546023025088675686, 26306121126614404878140942547851336824280012, 36992338394729996934810822203785341396977760, -59766833082223644334194762397946083574100377, 30503383409680673917467675836055391410397665, -2799111519868687344382212032745426107709678, -4842454821071196346639304001951452140553199, 2573270290539028456479604649930727035014918, -394261530010879306831864975392720248306274, -167259642214274798612250399219366919493957, 129782025267106444256140539802668882185950, -52255962774885768243484037389635190961962, 13677515241185808493579550564776826214879, -2005737292621536212695141860598642769669], 29110346610161550664604699760567702156999889], [[-19028158976380362467419657701821497987371183, -79021957244620131510545550633397965548393327, -134421160544560843215050739464241950247308909, -155865876575317520422781629729294553472700131, -140696577660948761302907558022246420039568972, -103056028132532329715681508623881643315880807, 54782177909415307928171225229985352439825135, 31938583921746475782180701449520749860035223, -25770191415582633997942765396740440849444554, -20301694007944581414465059429963233985743231, 25019654990662246734311189454033101072180642, -8460560557240589442197951136922611620069311, -1660482988629234569071834202469189376000068, 2085477002723189962990452419920485557492284, -583861312255549574619134758444261841466014, -27780330547677343669064365261717649959960, 73808435726185368423907602750640398416208, -38197898222269150842461234182414627930607, 12035973967276170294747042600137143155064, -2221789445757788061277685699506258155052], 29110346610161550664604699760567702156999889], [[-1114349091664248416738457323921660351081632071, 876850790900701103400319879551236110292643836, -4129518810771028669641461674361223388853847896, 5327782879281626908745423404027727596003249728, -4417097117617313283484592211614992215108580617, 3878057225845205498006336180908370449991824300, 1920258556262827472959513665600520473458680828, 1034723265867950269408291913031928590303834186, -5560888136352663903330509793002597927030879321, 5114639994484842134480896245658744655539905003, -1893187054873097517986832545372893564701034697, -112581813996874305595475171446476457674280796, 423301006817828109674535178784607090474455138, -170471816871757409864948670267689364821628430, 13220528548825257287397142272390898368918746, 17061668476056591168623101741250929382571997, -10470168327059390676123169619155571297507149, 3800411864093681175561839799428165747248369, -907986257943606769966123854360474718869949, 117252747266493611275045422672537013896426], 1251744904236946678578002089704411192750995227], [[-17990858330148992938138648349124123789187187, -96482964295070506144523338125743965991442669, -183669199491076213494486730386063744313656185, -252025599169981321983890963620444851790248526, -116796175793856370308539517043758969715176512, -173198316489951412138277696944389582149607568, 15463283582689077517197808128817627456373578, 61608009995522702098900066580844536356795261, 16415194510820639229793014628048354655580531, -83950107134558005674634467347299066784285856, 56290666754214240075270615657048681339319264, -10907851546595861263526086001085226267440605, -6764508763380753858265113505817040213869130, 4725754445046116597061991168135343996279643, -978626595583853022005906384041712173283139, -201786727847305372251577530666239324126801, 207237889695099315642111529703320841268463, -91496540290036144731746617046440549407747, 25863930142098088988580137795250629294900, -4229206178064690302252628406627357898750], 29110346610161550664604699760567702156999889], [[-2545480655376397392258502898117829680701398079, -7508627718832573733116056609182936459580845588, -13508824145055419259346612295469551913836647903, -12519939271623249983624749307723673167213414146, -10644802420508148856390698361225427600046391863, -8694022482655946043070852904173211345574669682, 2498334460561762133229675563995032602427517044, 4128098685953274705800929397850358042583524464, -2022944902650590166384292381535662860247342323, -2376588722857812088251240969910216616619413133, 2451556432814763160416452302905002496682369142, -743624096929602814519434358083901451677973877, -186926693162752636099876370998290981051336990, 200414550820737750416535276479082350088170282, -53713685661154489828879229470551672757390423, -3242420008434205799987285846162959573084374, 7177612088435134611917969703855980216653146, -3622866594477088438481259103242599919321219, 1116896082088153429627017407859402202778809, -200523797611813247795484751310857306979096], 1251744904236946678578002089704411192750995227], [[-5041868132459225284826953174919091597546318, -52531468784476571078934318479727770784294099, -69298292376483878108336608441717473274153492, -220473207727382898143678128791219767860866242, -60746608246889638891989591573622996209468216, -194720239648704063736792434459094092789446535, -16305385253498511551843901305695118388818528, 63248553188971649177506357148415763586151472, 58568361157631637825179457942563068933702530, -121884247483945798413306648370974812863289051, 68790935209586631216255483405645845556812595, -9053565544954661855188371027324042429429647, -9898759283684005760461545348422099645993912, 5797626276147711407962041198571213066329278, -1008600903136705470762777490480447482741922, -325165321325610709963102227619481136164002, 276803432472810983081886119619983738863471, -115332307105446301074326389617356549869189, 31118701662728263692695021472206708265661, -4755111031270816332926774844773317104451], 29110346610161550664604699760567702156999889], [[1418920515113353215857126968188543622410344555, 8930865211862482893739356514991224143919852107, 12162199391591334429191832991620205627865401023, 18623816192578258609806062540436777229953991858, 9631888859661635158306830157177849023712138805, 10101420194422364912626490367505390534025584352, -2777282293268802948444836192709471113446464192, -2834080987651923730023400535695726050103961950, -300772461032033547416687939094296345519350922, 4283870553654264893577138178317896633562821848, -3149266132367829392246414241312596961206881087, 708640904223161125286532360865293960654043728, 346916127218549490408750225494960385291784557, -267466892724795627607231323277254061529012020, 59274614578526796632025789982858838055700248, 10191907083318545279037094137324182556196044, -11436672842476163884727693126663881763561032, 5180776327862800698636194447004047264983544, -1498392787620220091731685986178094257054922, 254194399934218396415362746733531673498642], 1251744904236946678578002089704411192750995227], [[-1299884345159121015553711826223740036054587400, -6911209313527333748333039478539790775399906705, -6904759453161412169956505992620557775460355564, -17115363054297051615147458146641180058051052429, -6891900108912637209990821045555200815789506806, -10692145828068984944713527784045709175726178251, 1141582798344748079353702102539565229752351290, 2821603031113148921471550535666348982195689217, 2285418022099733216366772146380868075632616991, -5964504584439974107945062376825295598125437986, 3663512908024330515136394570292629975468462152, -607410172121101613365883469105000987854656339, -485600176971861866163438171250069744318547767, 312001101843467460633806497502693055743474326, -59537324348623981356134402867054447914163988, -15722890887651145824632388004509387020324080, 14442719651902614401939382225546865041389405, -6186003704029554394946680343166541266503092, 1713138061806239321603987412228325437777610, -273942529245770302251899769959228976152420], 1251744904236946678578002089704411192750995227], [[4881296380586525085850382509831523432609876026, 15311227857391716236986168903392591653247207113, 16717131740407456418326107878574547627127692542, 25044924273142388872686143979033265801794176922, 9430401041186318729123154813217212112619012603, 13403763761998702602455981285001238949310795095, -2475798485846370849567109187194127604940863653, -3009416963905994002405192053451936305857682734, -2238079357599931348226738534969711926156039066, 6803394535698839505964039768345965594680940421, -4366458264702001707315323433217274440078871250, 805923194780101981695666996902736086547653013, 551790865757698242832232809117802370985566881, -374506755053897729375412067176675905257108691, 75150450604061837376334299217791559866169282, 17775342555439190680758524409183755913988262, -17087052485080211515845014990363017070565399, 7431878061255504682034823155340586505629721, -2085415926976752965748602877793229424318285, 343323824183708251153127694695551889296755], 1251744904236946678578002089704411192750995227], [[-1743565235057086951158192797628580752731400484, -7824068823330072702849825552967039472251019244, -10935527863736572544824107434522799048116539302, -22209353512561473336159013383401773550927483319, -6470511907728473823571276819308160161984206484, -14521900172634285389076806868172285527096804525, -842122873233526490452312776018460288379676521, 5006447270232740503800687729011396683607855410, 3695933987895934033908896329456381787815931413, -8921876465162868686852995190840638848215719983, 5278356684277555461208032488218592549201252519, -800826026796262922370670988870133085023166354, -720298238575837122698803716817089936488498375, 445707379103914465807455605461535547782322579, -82570956392565991840969189417970216292193127, -23103984020233989877739712191046378634356197, 20745591395940810907502587928127754548775576, -8801019200705146156103617101606301456311914, 2411305842156930772756324864797511414611408, -378937213816360169312208722683137819873304], 1251744904236946678578002089704411192750995227], [[-921447926119676625150803621077367524552345480, -8775104167539764724970664275789054553333459965, -13491954165101296417185415019840893750759567302, -23915414910452985237086359677986300629294511600, -10498172826234148634453704699965035828066636277, -19637627153908548375855718775283248815349554779, 1643710377433769246084072307694304808992827869, 6707707153826265044765686552963309550298091396, 2080154649029189763871319095269094561609019101, -9215029537913918629650957056049070148004190139, 6039505662823078578738338170598428885384440679, -1110115149324653792320852665662741127210626346, -746368253464735724260932989626420483931676016, 504792648761786606468690444584603347980954006, -101469001193897411255750245940783060425445312, -22644437037638434762378374334094883909672108, 22440729900066341764568249627648722150003208, -9810368706267005830018606825718721754151353, 2750628896360193603019078769053861843091122, -442515325032101452730689713995848790403981], 1251744904236946678578002089704411192750995227], [[2548420374675628966973447962518141880283251377, 10014604919277965644272298576426067465114409833, 19319516650749698416191199793606108623488376243, 27746146753027315148126927208093470438545839048, 15906013940079213431002291741865278245803774363, 18857700893032918842272847046967691034171308455, -2131807494142067400676003450065960379763060746, -7915025105414643015534932623625292306904936054, -118177137793121924931153013515687093279754864, 8386271343987591924712912936728008443932070089, -6121193940422332234864946776866966129913931040, 1336136591980469120303942362624912127720829741, 672408336800642999517683677105774539433383453, -508773705311719504584162047383595435962196019, 112328969224288326818518015471694894695598608, 18461454762759421612343935024670275045633049, -21280177327984833725064369049333388380680151, 9662320107357429864391891526700255244111814, -2783872714132765702280002146641660571638916, 463557975193593275609438031808879127117357], 1251744904236946678578002089704411192750995227], [[-5398831275920882376938732174220079950763328264, -13016467765421322384341097091569605126451800217, -28030917509829472416234300056305760357916381542, -33629947903535796648047246661368134501312435376, -20948224490276663775677330472785369993024656198, -28649428745379272694650375285803325733437118821, 1152838211299819836767102528608981438741045502, 14993270406538347295898954165862034100770646098, -2289840497791072987353999261478598533069040760, -11182621403333001763100898383537754220089033200, 8768017011576575637034598195402697148788638161, -2058128329676333735668953877008935405120254149, -884899481285894829983406888600289704051694842, 712444475836912663358272622669891941102595062, -165285921958765020907510055556561842527634586, -21303267786443331133905066112810181206743265, 28247528829627132072631778136427329076880090, -13173729192724017851766940450242630023122468, 3847373494653494452939791954569444825659599, -644049701806838400400484046796737491809246], 1251744904236946678578002089704411192750995227], [[689388382579571453437606725561648245735968421, -12756220188872206141103793231204803375128504932, -20118970982950544458012382760801630297374134239, -41245709672006677332066388249519955607349686975, -21299869045942406672875915473947606240102204806, -31496329272524651413258733077232707375208450133, 4533799750016680608220693268620777230822701276, 10757382723547839483232851239349152487315751535, 1971262783327153697641543937139705618530512973, -13956309177999501107776566607267219060412836299, 9618688085208832446031707816681381848596771812, -1922036673435333997659202720684324470868853593, -1132067628705635264187963258936634649801301124, 803952972738634771504814801709478117677065787, -168021378053902963270015086046831656548689958, -33444869318133262612455394750818519928631543, 34973487767578894699359786304709080396911060, -15523086498307914924920281282847508414521486, 4406814217003530316054819335760059062009399, -719421665515393007351092852122991154098031], 1251744904236946678578002089704411192750995227]]

hecke_ring_character_values = [[461, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [277, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [511, [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0], [-1, 0, 1, 0, 1, 0, 0, 0, 1, 0, 1, 0, -1, -1, 0, 1, -1, 1, 0, 0], [1, -1, 0, 0, 0, 0, 1, 0, -2, 0, -1, 0, 0, 1, 0, 0, 1, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, -1, 0, -1, 0, 0, -1, 0, 1], [-2, -1, 1, 0, 2, -1, 0, 0, 2, 0, 2, 0, -2, -1, 0, 2, 0, 2, 0, 0], [0, 0, -1, 0, -1, 0, 0, -1, 1, 0, 0, 0, 0, -1, 0, 2, -1, 0, 0, 1], [-1, -2, 1, 0, 2, 0, 1, 1, 1, -1, 1, 0, -1, 1, 0, 1, 1, 1, -2, 0], [1, 0, 0, -1, 0, 0, -1, 1, 0, 1, 2, 0, 0, 0, -1, 1, 0, -1, -1, 0], [2, 0, -2, 0, -5, 0, -1, -1, -2, 0, -2, 0, 2, -1, -1, -2, 0, -2, 1, 1], [-3, -1, 2, -1, 1, -1, 0, 3, 3, -2, 4, 0, -3, 1, 2, 2, 0, 1, -1, 0], [-3, 1, 0, 0, 2, -2, 2, 0, 1, -1, 0, 0, -1, -2, 1, 0, -1, 0, -1, 1], [-3, -1, 3, 0, 1, 1, -2, -1, 4, 0, 4, -2, -3, -4, 0, 2, -6, 5, 1, 1], [-2, 3, -1, 1, 3, -1, -2, -2, 4, 1, 3, -3, 1, -5, -1, -1, -3, 2, 0, 1], [-1, -1, 3, -1, 5, 1, 2, -1, 1, -1, 2, 1, -2, -1, 1, 5, -2, 1, -2, 0], [1, 0, 0, -1, 0, -1, 0, -1, -4, 0, -2, 1, 2, 2, -1, -2, 1, -3, -1, -1], [-4, 1, 5, 0, 1, 1, -1, 0, 1, 1, 1, 2, -1, -3, 0, 4, 2, -1, 0, -2], [1, 0, -1, 0, 1, 1, 0, 0, -2, 0, -5, 0, 4, 0, 0, 1, -2, 0, 1, 0], [-3, 0, -1, -2, 1, -4, 2, 2, 1, 1, 4, 2, -3, 0, 4, 3, 4, 0, -1, -1], [3, 0, -1, 0, -1, 2, 0, -2, -1, 1, -2, -2, 3, -1, -2, -3, -5, 3, 2, 2], [-5, 0, 3, 2, 0, 0, 1, -1, 2, 1, 2, 1, -3, -3, 1, 4, -1, 5, 0, 2], [-2, -2, 0, -2, -1, -2, 0, 2, 5, 0, 7, 1, -5, 1, 3, 2, 1, -2, -3, -1], [-2, 0, 1, 2, 0, 4, -4, 0, 1, -1, -2, -2, -1, 1, 1, -2, -1, 0, -1, 0], [2, -3, -2, -1, 0, -1, 1, 1, 0, 0, 1, 3, -1, 0, 1, -1, 1, -2, 0, 0], [1, 3, -2, 4, -4, 2, -1, 0, -3, 4, -1, -1, 2, 1, 0, -2, 1, -1, 0, 2], [2, -1, 5, 0, 5, 2, -2, 0, -1, 1, 5, 0, 0, -5, -2, 5, -4, 0, 1, -1], [-1, -2, -3, 1, 1, 0, 0, 2, -5, 0, -4, 2, 2, 2, -1, -1, 2, -4, 1, 1], [4, 3, -1, 3, -5, 2, 0, -2, -3, 2, -9, 0, 7, 2, -2, -7, 3, -4, 2, 0], [-5, 1, -1, 0, 1, 0, 1, -1, 1, 1, 5, 0, 0, -1, 1, 3, 0, 1, 0, 1], [-3, 0, 4, 1, 5, 1, -1, 1, 5, -3, -1, 1, 0, 2, -1, 0, 2, -3, -2, -2], [4, 2, -6, 0, -4, 2, 0, -2, -1, 2, -6, -1, 0, 2, 0, 0, 2, -1, 0, 0], [4, 6, 0, 4, -7, 4, -6, -3, 0, 0, -8, -4, 6, 1, -3, -3, -3, 1, 4, 2], [3, -1, 1, 5, 3, 2, 2, -2, -3, 1, -2, -1, 0, 1, 1, 5, -2, 1, -2, 0], [-2, -1, 2, 1, 4, -1, 2, 1, -5, -2, -4, 2, 5, 6, 1, -3, 6, 1, -2, 0], [-2, 0, -6, 0, 2, 0, 0, 0, 6, 0, -6, 0, 0, -3, 0, 0, -3, 6, 0, 0], [-1, 1, 3, -1, 5, 1, 2, 1, 7, -2, 7, -1, -7, -4, -1, 1, -1, 6, 1, 1], [1, -3, -8, -1, 3, 0, 3, -1, -2, 1, 0, 2, 0, 8, 2, -3, 5, -1, -3, -1], [-4, 0, 3, -1, -2, -1, 1, 4, -2, -2, 1, 4, 4, 2, 1, -4, 1, 0, -2, -2], [2, 2, -6, 0, -5, -2, 2, 3, -3, 2, -2, 2, 1, 3, 2, -4, 6, -7, -1, -3], [-3, -2, 4, -4, 3, -4, 0, 2, 12, -4, 8, 0, 1, -3, 3, 4, -3, 8, -4, -3], [-6, 1, 4, 0, 4, -4, 1, 3, 8, 0, 4, 1, -4, -3, 0, 0, -1, 1, -3, -4], [5, -1, -5, 2, 3, 4, 1, 1, -4, 1, 2, 1, 2, 3, -2, -6, 4, -5, 0, 1], [2, 0, 0, 2, -12, 2, 0, 0, -9, 0, -10, -3, 9, 7, 0, -7, -1, -4, 3, 1], [8, 1, -4, 0, 1, -2, 2, 0, -2, 2, 2, 0, 7, -4, 1, 2, 3, 6, 2, 1], [0, 0, 5, 4, 4, 0, -1, -4, 0, 1, -8, -1, 0, -6, -2, 0, -1, 5, 2, 1], [-7, -4, 10, -4, 6, -3, -1, 3, 13, -3, 5, 0, -1, -4, 3, 8, -4, 7, -3, 1], [-5, -1, 11, -2, 1, 0, -3, 1, 8, -1, 7, -1, -9, -8, -1, 8, -7, 7, -1, -2], [-4, -2, 0, -4, 5, -4, 2, 1, 7, 0, 3, 1, -5, -1, 1, 12, -2, 11, -1, -1], [15, 1, -18, 2, -11, 3, -1, -1, -14, 1, -12, -1, 2, 13, -2, -19, 12, -15, 0, 1], [0, -1, -1, -4, -2, 1, -1, -1, 10, 2, 11, -2, -8, -7, 1, 6, -6, 1, 1, 0], [3, 2, -7, -1, -6, 1, -1, -1, -5, 3, -2, -2, -1, 2, 1, -3, 7, -3, 0, 3], [8, 3, -3, -2, -3, 2, -2, 0, -1, 1, -2, 2, 10, -1, 0, -2, 0, -10, 1, 3], [-12, -4, 3, -5, 12, -7, 0, 4, 11, -7, 8, 2, -7, 5, 5, 5, 5, 6, -5, -5], [3, 0, -5, -1, 8, -2, 1, 2, 8, -1, 2, 2, -4, -6, 2, 4, -1, 3, -2, -2], [3, -2, -7, 1, 2, 0, 2, 0, -6, 0, 10, 2, -2, 0, 2, 4, -6, 3, -2, 1], [-6, -6, 0, -6, 1, -6, 6, 6, 1, -6, -1, 7, -1, 7, 10, 6, 7, -6, -10, -7], [5, -3, 0, -4, 2, -4, 3, 1, -6, 0, 8, 2, -1, -5, 1, 5, 8, 3, -2, 0], [1, 1, -2, -1, -1, 0, -1, 0, -9, -1, -10, -1, 2, 1, 0, -1, 9, -10, 0, 0], [0, 0, 2, -2, 0, -2, -2, 2, 4, 2, 4, -2, -5, -5, 0, 2, -4, 0, 2, 0], [5, -7, -4, 2, -2, 0, -1, -2, -11, 2, -5, -1, 4, 3, 0, -2, 9, -3, 2, 0], [3, 2, 0, -2, -4, -2, -2, 1, -11, 0, 3, -1, 2, -3, 1, -7, 3, -6, 1, 2], [-2, -2, 1, 0, 3, -1, 5, 1, 3, -2, 2, 1, -9, 1, 5, 7, -3, 5, -1, -1], [-8, -1, 7, -1, 18, -7, 3, -5, 14, -4, 8, 0, -4, -5, 4, 15, -8, 9, -7, -3], [3, 1, 4, 6, -3, 4, 0, -1, -8, 4, -2, -2, 2, 1, -4, -6, 1, -2, 6, 4], [1, -3, 2, -3, 10, -3, 3, 0, -2, 2, 4, 3, -4, -9, -1, 4, 1, -5, 2, -3], [-8, 0, 6, 0, 8, 0, 0, -4, 6, 0, 2, 0, -6, -12, 0, 8, -10, 6, 4, 0], [-3, -4, 8, -5, 13, -5, 5, 0, 6, -6, 11, 5, -1, -3, 1, 11, -4, 8, -6, -4], [-1, 2, -2, 2, 9, -2, 3, -2, 0, -2, -2, 0, 1, -3, 2, -3, -4, 5, -2, -3], [-4, 0, 1, 1, -8, -3, -1, -2, -8, 1, 3, -2, -5, -3, 3, 5, -2, 5, -1, -1], [-3, 0, 3, -2, 0, 0, -4, 5, 3, -5, 6, 2, 3, 5, 2, -3, -4, -5, 0, -2], [-13, -7, 8, -7, 3, -5, -2, 1, 13, -6, 13, 0, -6, 2, 6, 6, 0, 4, -5, 2], [2, 4, -3, -2, -10, 3, -3, 0, -4, 4, 0, 2, 2, 2, -1, 0, -1, 1, 4, 4], [-7, -2, 8, -9, 10, -3, 2, 3, 9, 0, 11, 0, -3, -1, 2, 14, -10, 2, -2, 0], [-2, 1, 1, -2, 4, 2, 3, -7, 1, -2, -2, 3, -1, -9, 0, 6, -10, 5, 7, 2], [-6, 4, -11, -1, 6, 1, 0, -4, -2, 1, -10, -2, 1, 1, 1, 1, 1, -3, -1, -1], [0, -3, 0, -3, -10, -1, 1, 3, 1, 0, -7, 0, 7, 3, 0, -15, 12, -3, -1, -1], [4, 0, -4, 4, -8, 0, -4, -5, -8, 2, 0, -5, 7, 3, 0, -7, 2, -2, 3, 3], [12, -3, 4, 0, -8, 1, -7, -1, -3, -3, -12, -1, 10, -1, -7, -9, 2, -2, 5, 1], [0, -3, -7, -2, -3, -3, 2, 2, 5, -2, 3, -1, -5, 6, 0, 0, -1, -2, 0, 1], [-8, 1, 7, -2, 8, 0, 0, -7, 2, -2, 7, 0, -7, -15, 0, 8, -9, 14, 7, 0], [3, -4, -7, 0, 6, -2, 1, 7, -1, 0, 10, 1, 7, 10, 0, 4, 10, 3, -7, -2], [18, 3, 0, 4, -11, 4, -3, -6, -12, 0, -16, 0, 17, 10, -6, -9, 12, -9, 0, -7], [-12, -1, -5, 0, 10, -6, 3, 1, 9, -1, 12, 6, -4, 1, 3, 11, 0, -3, -1, -1], [2, 2, -12, 4, -2, 0, 2, 0, -3, 0, -5, -3, 10, 8, -3, -13, 0, -6, 2, 4], [3, 0, 0, -2, -15, 3, 2, -3, -15, 4, -3, -3, 2, 4, -3, -2, 1, -4, 0, 0], [6, -2, -3, 0, -6, 1, -1, 6, 3, -2, -6, -1, 4, 6, -1, -4, 9, -10, -10, -6], [0, 1, -8, 2, 0, 0, 0, -1, -7, 0, -10, 1, 9, -10, -1, -2, -10, -5, 2, 1], [11, 6, -10, 3, -4, 2, -1, -1, 2, -1, -8, -6, 3, -1, -3, -14, 3, -11, 0, -1], [-10, -3, 16, 3, 15, 2, -1, -2, 15, -1, 18, 1, -16, -13, 3, 14, -12, 3, 1, 0], [0, -1, -10, -1, 2, 1, -3, -3, 2, -4, -1, 1, -1, 2, 1, -13, -7, 0, 0, -4], [-12, 3, 0, 0, 4, 0, -3, -1, 1, 0, -1, -1, -4, -1, -1, 11, -14, 12, 1, 0], [-9, -8, 12, -3, 8, 0, 5, 7, 5, -7, 16, 7, -5, 9, 7, 6, -1, 2, -8, -3], [13, 6, -12, 3, -6, 0, 4, -5, -11, 5, -11, -5, 9, 1, -5, -12, 0, -6, 6, 3], [4, 7, -7, 7, -4, 0, -1, -4, -7, 5, -19, 0, 20, 11, -5, -17, 3, -16, 0, 1], [21, 1, 0, 1, -1, 1, -1, -1, -1, 0, -12, 0, 2, 11, -1, -8, 20, -8, 0, -3], [0, 0, -5, 2, -10, 4, 2, 2, -4, 4, -8, 0, 2, 0, -2, -3, 8, 0, 0, 4], [-7, -2, 6, 1, 6, -2, -3, -3, 19, -4, 1, 2, 1, -15, -1, 1, -1, 7, 0, -4], [3, -3, 4, -3, -9, 1, -2, 1, 3, 4, -2, 0, 3, -6, -4, 2, 6, 2, 1, 2], [-8, -2, 14, 0, 9, 0, -8, 1, 10, -2, 8, 0, -16, 1, -8, 1, -23, 5, 7, -1], [9, 1, -7, -1, -9, 5, 0, -1, -13, 5, -6, 13, -3, 6, 1, 1, 6, -14, -1, -1], [-9, 2, 3, -5, 4, -3, -5, 6, 21, -5, 3, -5, -3, -3, 0, 1, -12, -3, -6, -3], [7, 0, -6, -3, 8, -2, 3, 3, -11, -3, 3, 3, 6, 10, 0, 6, 16, 0, -3, -2], [-10, -8, 1, -7, 10, -2, 0, 8, 6, -2, 8, 11, 5, 9, 2, 7, 9, -1, -7, -2], [-10, -7, 11, 0, 22, 0, 2, 1, 11, -7, 10, 0, -12, 1, 2, 12, -9, 12, -9, -1], [3, 2, 2, 1, -2, 0, 5, -3, -7, 3, -2, 3, 13, 1, 3, 0, 3, -12, 2, 1], [1, 0, 8, 5, -12, 9, -5, 1, -12, 0, -9, 1, 15, 9, -9, -15, -1, -8, 4, 4], [-8, 4, 8, 4, 8, 0, 0, -4, 7, 0, 4, -9, -4, -4, -2, -4, -4, 11, 4, 2], [-11, 1, 11, -3, 11, -3, -1, 5, 7, -3, 5, -1, -11, -6, 0, 8, 1, 0, -5, -3], [-1, 1, 5, -1, 6, -2, 1, 2, 7, 0, 6, 0, -1, -2, -1, -12, 12, -1, -1, 0], [-5, 2, -13, -1, -7, 1, 0, 0, -7, -1, -7, -2, -1, 8, 1, -13, 7, 5, 0, -1], [12, 0, 0, 2, -12, -1, 1, 0, -7, 7, -8, -2, 5, 5, 0, -8, 0, -3, 7, 0], [-1, 1, -6, 1, -12, 2, -1, 3, -8, -2, -8, 0, 7, 10, 2, -11, 9, -8, 2, 1], [-1, 5, 7, 2, -5, 0, -3, 1, 2, -1, 5, -3, 9, 1, -3, -9, -13, -7, 5, 2], [-12, 0, 9, 4, 5, -3, -4, 1, 5, -2, 3, 1, -1, -17, 3, 1, -4, 7, 3, 3], [-5, 3, -2, -2, -4, 3, 6, 2, 8, -6, 0, 1, -8, 3, 4, 5, 1, -5, -4, -1], [2, -6, -3, -2, -5, 8, -3, -3, -7, 5, 2, 6, -2, 2, 2, 4, -8, -2, 0, 5], [-6, 8, -2, 19, -9, 5, -7, -5, 3, 4, -5, -4, 6, -2, -8, -8, -7, -8, 7, 0], [-2, -2, 5, 2, 12, 1, 8, 8, 7, 0, 10, 2, 2, -7, -2, 3, 10, 2, 0, 0], [14, 5, -7, 0, -5, -1, 1, 0, -6, 6, 3, 0, 13, -6, -3, 3, 2, -14, 6, 5], [5, 9, 4, 9, -4, 3, 0, -8, 1, 2, -19, 0, 16, 2, -2, -14, 1, -4, 3, 0], [8, 5, -19, 0, -14, 2, -1, 3, -9, 5, -8, -2, 10, 3, -1, -13, 12, -23, -1, -3], [-14, 2, -3, 0, 0, -1, 3, -4, 3, 2, 14, 1, 2, -4, 3, 10, 1, 4, -8, 4], [14, 9, -11, 8, -17, 9, -6, -8, -12, 6, -10, -4, 12, 7, -7, -14, -4, -13, 7, 4], [0, 7, 0, 7, -4, 7, -7, -1, -3, 0, -11, 0, 5, 10, -1, 3, -1, 3, 0, -4], [8, -4, -3, 7, -1, 3, 2, -3, -9, -3, -5, 3, 10, 14, 4, -9, 15, 4, -2, 0], [19, 7, -17, 4, -19, 9, 0, -7, -26, 9, -21, -5, 14, 5, -5, -4, 5, -22, 4, 5], [-4, 0, 3, -3, 0, 0, -6, 2, 8, -2, -3, -1, 12, 4, -1, -5, 2, -15, 0, -3], [18, 9, 0, 0, -24, 7, -9, -9, -10, 9, -18, -7, 0, -9, -9, -10, -18, 0, 21, 9], [0, 9, 9, 6, -13, 11, -11, 0, -10, 10, -2, -6, -1, -6, -10, -2, -18, -3, 10, 9], [-6, 1, 7, 1, 12, 1, -1, -1, 4, 2, 13, -1, 1, -6, -1, 8, -9, 6, 0, 2], [-9, 0, -12, -1, 7, -6, 4, 4, 0, 5, 13, 0, -1, -5, 1, -6, -7, 9, 0, 5], [-7, 5, 0, -2, 9, -2, -5, -4, -3, 0, -1, -3, -8, -6, -4, -9, -14, -6, 3, -7], [-1, 3, 7, 3, 17, 4, -4, -5, 3, -1, -8, 0, 8, -15, 1, 15, -25, 16, 4, 4], [-1, 0, 11, 2, 6, 10, -2, -7, 6, 0, -10, -7, -7, -7, -10, 7, -8, -2, -4, -4], [17, 0, -16, 2, -21, 1, -2, -2, -21, -1, -1, -2, 17, 23, -1, -17, 11, -12, -4, -4], [14, 11, -1, 9, -3, 11, -7, -9, -9, 7, -21, -11, 9, -10, -13, -14, -11, 8, 13, 11], [-8, -1, -12, -4, 17, -12, 12, 0, 8, -8, 8, 4, -1, -8, -1, 8, 13, 4, -8, -1], [7, -7, -9, 1, 13, -3, -2, 0, -6, 1, 2, -2, 9, 7, 0, 10, 9, 2, 0, -3], [-1, -6, -6, -6, -17, -1, -7, 8, -5, 7, 4, 0, 4, -8, -7, 4, 11, 1, -1, 7], [6, 1, -20, 4, -1, 0, 6, -6, -12, 6, -7, 2, -2, 9, 2, -8, 8, 6, 1, 4], [-26, -7, 15, 0, 14, -8, 11, 3, 1, -7, 26, 8, -2, 3, 11, 9, 12, 23, -11, -3], [-2, 5, 0, 4, -8, 4, -5, -6, -15, 0, -9, -3, 11, 0, -6, -11, -11, -8, 3, 7], [19, -14, -9, -3, -3, -1, 3, 0, -19, -3, -9, 3, 9, 19, 0, -4, 20, -9, 0, -1], [0, 1, 3, 5, 5, 2, 2, -2, -9, -2, -10, 2, 1, 0, -1, 2, -1, -1, -2, 0], [-4, -1, 1, 0, 5, -10, 4, 10, 8, 1, 9, -1, 9, 10, 1, -12, 17, 1, -4, 0], [3, 4, -13, 7, -3, -1, 0, -4, -11, -1, -20, -13, 10, -2, 0, -7, -2, -4, 7, 0], [0, 0, -4, 4, 2, -4, -4, 1, 2, 0, 4, 1, 6, 14, 4, -6, 13, -9, 0, 0], [0, -9, 6, 0, 7, 5, 7, -4, 7, -9, 0, -5, -5, -4, 7, 18, -2, 17, -4, 4], [15, 6, -12, 6, -15, 8, -3, -12, -20, 10, -14, 0, 9, 11, -10, -13, 4, -21, 8, 3], [5, 3, 7, 1, -5, 3, 0, -3, 10, 3, 6, 4, 15, -7, -1, -1, -7, 11, 1, 1], [-8, -6, -5, 2, -4, 5, -2, -2, -19, 9, 3, 6, 2, 10, -2, 2, 4, 8, 0, 9], [-13, -11, 0, -12, 16, -12, 11, 10, 10, 0, 21, 12, -14, 1, 10, 16, 9, 4, -12, -4], [4, -6, 11, 5, 18, 4, -4, 0, 5, -5, -13, -5, 3, -7, -8, -13, -5, 9, -5, -6], [11, 8, -1, 4, -3, 8, -2, -4, -6, 2, -32, -1, 6, 0, -5, -11, -1, -2, 5, 1], [-5, -8, -4, -10, 13, -8, 7, 10, 17, -7, 11, 1, -17, 5, 8, 5, 1, 12, -8, -1], [9, -2, -2, -5, -15, 1, -1, 0, 0, 0, 1, 5, 7, 17, -1, 1, 4, -6, 0, -2], [-26, -5, 6, -8, 11, -6, 5, 6, 24, -6, 29, 6, -14, -9, 5, 16, -6, 5, -5, 0], [9, -9, 0, 1, -2, 0, 0, 0, 7, -7, 1, -1, 7, 18, 10, 1, 9, -21, -7, -9], [8, 2, -3, 0, 0, -1, 7, 6, -7, 2, -8, 1, -8, 6, 7, -6, 5, -2, -8, -6], [7, 0, -11, -5, 8, -4, 5, -5, 8, 2, 4, -5, -8, -19, 4, 8, -9, 13, 2, 2], [5, -4, 4, -7, 4, 0, -9, 3, 8, -3, 5, -6, 5, 5, -6, -7, -7, -12, -4, -7], [-14, -7, 10, -3, 13, -7, 8, 3, 4, -8, -8, -5, -4, -15, 3, 14, -5, 18, -3, 5], [-2, -12, 3, -8, 11, -5, 8, 5, 16, -6, 28, 6, -8, 4, 12, 9, 11, 12, -8, 0], [6, 13, -7, 3, -13, 5, 4, -10, -27, 3, -20, 4, 7, -4, 0, -8, 12, -10, 10, 5], [-8, -11, 5, -10, 8, -10, 0, 11, 18, -10, 15, 9, 3, 18, 8, 10, 18, 8, -10, -8], [-12, 3, 1, 0, -3, 5, 2, -4, 11, 3, 12, -5, -28, -4, 2, 17, -30, 7, 3, 4], [10, 0, -18, -8, -14, -8, 8, 1, -14, 10, 8, 1, 5, -3, 8, -5, 10, -2, 3, 3], [-15, -4, 8, -4, 3, -9, -3, 10, 17, -3, 14, 0, -2, 5, 3, 0, 3, -2, -9, 3]]
